(************************************************************************
*    This File is Part of the AHM Triton Tools                          *
*    for Borland Delphi and C++ Builder.                                *
*************************************************************************
* Copyright  1995-2000 Alexander H. Mehlhorn (AHM) and Tritontools.com *
* All Rights reserved.                                                  *
*                                                                       *
*    For more Information contact us at                                 *
*    E-Mail : support@tritontools.com                                   *
*    URL : http://www.tritontools.com                                   *
*                                                                       *
*    AHM is copyright by Alexander H. Mehlhorn                          *
*    All Parts of this Collection were developed,                       *
*    designed and implemented by AHM                                    *
*                                                                       *
*    Under no Circumstances may you distribute this file                *
*    in this or any other format. This File is supplied                 *
*    as Evaluation of Source only. No Delphi Components may be developed*
*    using extracts or subsets of this code without expressed permission*
*    by AHM.                                                            *
*                                                                       *
*************************************************************************)
unit AHMTRTFFile;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,AHMFreeware;

type
  TAHMRTFFile = class(TComponent)
  private
    FAbout : TAHMAboutFreeStr;
    ffile : String;
    ftexty : TStrings;
    procedure SetTexty(value : TStrings);
    Procedure GetBegin(const XX : TStrings);
    Function GetEnd : String;
  protected
  public
    constructor create(AOwner : TComponent); override;
    destructor Destroy; override;
    Function Execute : Boolean;
    Function AddFootnote(xID,xLabel : String):String;
    Function AddHidden(xLabel : String):String;
    Function AddUnder(xLabel : String):String;
    Function AddDUnder(xLabel : String):String;
    Function AddKeepNext(xOn : Boolean) : String;
    Function AddTab : String;
    Function NewPage : String;
    Function AddPlain : String;
    Function AddFont(xNum,xSize : Integer):String;
    Function AddEnter:String;
    Function AddBold(xOn : Boolean): String;
    Function AddColor(xOn : Boolean): String;
    Function AddText(xText : String): String;
  published
    Property About : TAHMAboutFreeStr read FAbout write FAbout;
    Property Text : TStrings read ftexty write Settexty;
    Property Filename : String read ffile write ffile;
  end;

implementation

Procedure TAHMRTFFile.GetBegin(const XX : TStrings);
var i : integer;
Begin
  xx.add('{\rtf1\ansi \deff0\deflang1024');
  xx.add('{\fonttbl');
  xx.add('{\f0\fswiss Arial;}');
  xx.add('{\f1\fmodern Courier New;}');
  xx.add('{\f2\fswiss MS Sans Serif;}');
  xx.add('}');
  if ftexty.count>0 then
    for i:=0 to ftexty.count-1 do xx.add(ftexty[i]);
end;

Function TAHMRTFFile.AddFootnote(xID,xLabel : String):String;
begin
  result:='{\fs16\up6 '+xID+'{\footnote \pard\plain \s245 \fs20 {\fs16\up6 '+
           xID+'} '+XLabel+'}}';
end;

Function TAHMRTFFile.AddKeepNext(xOn : Boolean):String;
begin
  if xOn then result:='\pard\keepn' else result:='\par\pard ';
end;

Function TAHMRTFFile.AddTab:String;
begin
  result:='\tab ';
end;

Function TAHMRTFFile.AddText(xText : String): String;
begin
  result:=xText;
end;

Function TAHMRTFFile.NewPage:String;
begin
  result:='\par \page ';
end;

Function TAHMRTFFile.AddPlain:String;
begin
  result:='\plain ';
end;

Function TAHMRTFFile.AddBold(xOn : Boolean): String;
begin
  if xOn then result:='\b' else result:='\b0';
end;

Function TAHMRTFFile.AddFont(xNum,xSize:Integer):String;
begin
  result:='\f'+IntToStr(xNum)+'\fs'+Inttostr(xSize)+' ';
end;

Function TAHMRTFFile.ADDColor(xOn : Boolean) : String;
Begin
  if xOn then
  result:='\par \tx400\tx2400\tx4400\tx6400\tx8400' else result:='\plain ';
end;

Function TAHMRTFFile.AddEnter:String;
begin
  result:='\par ';
end;

Function TAHMRTFFile.AddHidden(xLabel:String):String;
begin
  result:='{\v '+xLabel+'}';
end;

Function TAHMRTFFile.AddUnder(xLabel:String):String;
begin
  result:='{\ul '+xLabel+'}';
end;

Function TAHMRTFFile.AddDUnder(xLabel:String):String;
begin
  result:='{\uldb '+xLabel+'}';
end;

Function TAHMRTFFile.GetEnd : String;
Begin
  result:='}';
end;

Constructor TAHMRTFFile.Create(AOwner : TComponent);
begin
  inherited create(AOwner);
  ftexty:=TStringList.create;
end;

Function TAHMRTFFile.Execute : Boolean;
var newlist : TSTrings;
begin
  if ffile<>'' then
  begin
    NewList:=TStringList.create;
    with Newlist do
    try
      GetBegin(NewList);
      NewList.add(GetEnd);
      NewList.SaveToFile(Filename+'.rtf');
    finally
      newList.free;
    end;
  end;
  Result:=True;
end;

Procedure TAHMRTFFile.SetTExty(value : TStrings);
Begin
  ftexty.assign(value);
end;



Destructor TAHMRTFFile.Destroy;
begin
  ftexty.free;
  inherited Destroy;
end;

end.
